package dojox.cometd;

import java.util.Map;
import java.util.Queue;

/* ------------------------------------------------------------ */
/** A Bayeux Client.
 * A client may subscribe to channels and publish messages to channels.
 * Client instances should not be directly created by uses, but should 
 * be obtained via the {@link Bayeux#getClient(String)} or {@link Bayeux#newClient(String, Receiver)}
 * methods.
 */
public interface Client
{
    /* ------------------------------------------------------------ */
    public abstract void remove();

    /* ------------------------------------------------------------ */
    public abstract String getId();

    /* ------------------------------------------------------------ */
    public abstract boolean hasMessages();

    /* ------------------------------------------------------------ */
    /** Take any messages queued for a client.
     * 
     */
    public abstract Queue<Map<String, Object>> takeMessages();

    /* ------------------------------------------------------------ */
    /** Deliver a message to the client
     * Deliver a message directly to the client. The message is not 
     * filtered or published to a channel.
     */
    public void deliver(Client from, Map<String,Object> message);

    /* ------------------------------------------------------------ */
    public void setListener(Listener listener);

    /* ------------------------------------------------------------ */
    public Listener getListener();

    /* ------------------------------------------------------------ */
    /**
     * @return True if the client is local
     */
    public boolean isLocal();
    
}